package cn.fw.shirasawa.common.utils;

import cn.hutool.core.thread.ExecutorBuilder;
import cn.hutool.core.thread.NamedThreadFactory;

import java.util.concurrent.ExecutorService;

/**
 * ThreadPoolUtil
 *
 * @author : kurisu
 * @version : 2.0
 * @className : ThreadPoolUtil
 * @description : ThreadPoolUtil
 * @date : 2023-04-19 17:31
 */
public class ThreadPoolUtil {
    private static volatile ThreadPoolUtil INSTANCE;
    private final ExecutorService executor;

    private ThreadPoolUtil() {
        this.executor = ExecutorBuilder.create()
                .setCorePoolSize(50)
                .setMaxPoolSize(200)
                .setThreadFactory(new NamedThreadFactory("shirasawa-custom-", false))
                .setAllowCoreThreadTimeOut(true)
                .useArrayBlockingQueue(1024)
                .build();
    }

    public static ThreadPoolUtil getInstance() {
        if (INSTANCE == null) {
            synchronized (ThreadPoolUtil.class) {
                if (INSTANCE == null) {
                    INSTANCE = new ThreadPoolUtil();
                }
            }
        }
        return INSTANCE;
    }

    public ExecutorService getExecutor() {
        return executor;
    }
}
