package cn.fw.shirasawa.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : DefeatTypeEnum
 * @description : 任务战败类型
 * @date: 2020-10-16 17:56
 */
public enum TaskDefeatTypeEnum implements IEnum<Integer> {
    A(2, "逾期"),
    B(4, "主动放弃"),
    C(5, "其他顾问成交"),
    D(6, "角色调整"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    TaskDefeatTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static TaskDefeatTypeEnum ofValue(final Integer value) {
        for (final TaskDefeatTypeEnum typeEnum : TaskDefeatTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final TaskDefeatTypeEnum typeEnum : TaskDefeatTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
