package cn.fw.shirasawa.domain.vo.follow;

import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.TaskStateEnum;
import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * @author : kurisu
 * @className : CustomerClueHistoryVO
 * @description : 客户跟进线索历史记录
 * @date: 2021-03-29 16:48
 */
@Data
public class ClueHistoryVO {
    /**
     * id
     */
    private Long id;
    /**
     * 跟进类型
     */
    private Integer type;
    /**
     * 跟进类型描述
     */
    private String typeDesc;
    private Long shopId;
    /**
     * 原始门店信息
     */
    private String shopName;
    private Long userId;
    /**
     * 原始跟进人
     */
    private String userName;
    /**
     * 是否完成
     */
    private String state;
    /**
     * 任务开始时间
     */
    private LocalDateTime beginTime;
    /**
     * 终止时间
     */
    private LocalDateTime closeTime;
    /**
     * 到期时间
     */
    private LocalDateTime deadline;
    /**
     * 任务战败类型
     */
    private String initiative;
    /**
     * 跟进次数
     */
    private Integer followRecordTimes = 0;
    /**
     * 超期
     */
    private Boolean overdue;
    /**
     * 活动名称
     */
    private String activityName;
    /**
     * bizid
     */
    @JsonIgnore
    private String bizId;
    /**
     * detailId
     */
    @JsonIgnore
    private String detailId;


    public static ClueHistoryVO with(FollowTask db) {
        if (Objects.isNull(db)) {
            return null;
        }
        ClueHistoryVO vo = new ClueHistoryVO();
        vo.setId(db.getId());
        vo.setFollowRecordTimes(db.getTimes());
        vo.setType(db.getType().getValue());
        vo.setTypeDesc(db.getType().getName());
        vo.setShopId(db.getFollowShop());
        vo.setUserId(db.getFollowUser());
        vo.setDeadline(db.getDeadline());
        vo.setOverdue(db.getDeadline().isBefore(LocalDateTime.now()));
        vo.setBizId(db.getBizId());
        vo.setBeginTime(db.getBeginTime());
        vo.setDetailId(db.getDetailId());
        vo.setState(db.getState().getName());
        if (TaskStateEnum.DEFEAT.equals(db.getState())) {
            vo.setCloseTime(db.getCloseTime());
            vo.setInitiative(db.getInitiative().getName());
        }
        return vo;
    }
}
