package cn.fw.shirasawa.domain.vo.follow;

import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import lombok.Data;

import java.time.LocalDate;

/**
 * 正在进行中的跟进线索
 *
 * @author : kurisu
 * @version : 1.1
 * @className : FollowTaskSimpleVO
 * @description : 正在进行中的跟进线索
 * @date : 2023-04-08 16:35
 */
@Data
public class FollowTaskSimpleVO {
    /**
     * 线索任务id
     */
    private Long taskId;
    /**
     * 线索描述
     * 活动为活动名称
     * 其他则为类型名称
     */
    private String taskName;
    /**
     * 线索开始日期
     */
    private LocalDate startDate;
    /**
     * 线索截止日期
     */
    private LocalDate deadline;
    /**
     * 跟进类型
     */
    private FollowTypeEnum followType;
    /**
     * 是否需要选择下次跟进时间
     */
    private Boolean choosable;

    public static FollowTaskSimpleVO with(FollowTask task, Boolean choosable) {
        FollowTaskSimpleVO vo = new FollowTaskSimpleVO();
        vo.setTaskId(task.getId());
        vo.setTaskName(task.getType().getName());
        vo.setStartDate(task.getBeginTime().toLocalDate());
        vo.setDeadline(task.getDeadline().toLocalDate());
        vo.setFollowType(task.getType());
        vo.setChoosable(choosable);
        return vo;
    }
}
