package cn.fw.shirasawa.domain.vo.pool;

import cn.fw.common.json.MaskMobilePhone;
import cn.fw.shirasawa.common.utils.StringUtils;
import cn.fw.shirasawa.domain.enums.CallStateEnum;
import cn.fw.shirasawa.domain.enums.FollowCloseReason;
import cn.fw.shirasawa.domain.enums.FollowStatusEnum;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * 跟进记录池vo
 *
 * @author : kurisu
 * @version : 1.0
 * @className : FollowRecordPoolVO
 * @description : 跟进记录池vo
 * @date : 2022-08-03 14:21
 */
@Data
public class FollowRecordPoolVO {
    private Long id;
    /**
     * 档案id
     */
    private Long customerId;
    /**
     * 客户姓名
     */
    private String customerName;
    /**
     * 车牌号
     */
    private String plateNo;
    /**
     * 手机号
     */
    @MaskMobilePhone
    private String mobile;
    /**
     * 归属地
     */
    private String region;
    /**
     * 车架号
     */
    private String vin;
    /**
     * 跟进类型
     */
    private FollowTypeEnum type;
    /**
     * 跟进人员
     */
    private String follower;
    private Long shopId;
    /**
     * 服务站
     */
    private String shopName;
    /**
     * 任务开始时间
     */
    private LocalDateTime planTime;
    /**
     * 任务完成
     */
    private LocalDateTime followTime;
    /**
     * 待办推送时间
     */
    private LocalDateTime todoTime;
    /**
     * 截止时间
     */
    private LocalDateTime deadline;
    /**
     * 完成跟进时长
     */
    private String consuming;
    /**
     * 状态 0: 进行中 1：已关闭 2：活动覆盖 4：其他覆盖
     */
    private FollowStatusEnum state;
    /**
     * 跟进方式
     */
    private String followMode;
    /**
     * 关闭原因
     */
    private FollowCloseReason reason;
    /**
     * 集团id
     */
    private Long groupId;
    /**
     * 拨打电话电话状态
     */
    private CallStateEnum called;
    /**
     * 完成跟进方式
     */
    private String closeDesc;
    /**
     * 客户转化方式
     */
    private String completeDesc;

    /**
     * 是否逾期
     *
     * @return
     */
    public boolean getOverdue() {
        if (Objects.isNull(state)) {
            return false;
        }
        return FollowStatusEnum.CLOSED.equals(state) && FollowCloseReason.OVERDUE.equals(reason);
    }


    public String getStateDesc() {
        if (Objects.isNull(state)) {
            return null;
        }
        return state.getName();
    }

    public String getTypeDesc() {
        if (Objects.isNull(type)) {
            return null;
        }
        return type.getName();
    }

    public String getCalledDesc() {
        if (Objects.isNull(called)) {
            return null;
        }
        return called.getName();
    }

    public boolean isFollowed() {
        return StringUtils.isValid(followMode);
    }
}
