package cn.fw.shirasawa.sdk.enums;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : CallEfficientEnum
 * @description : 通话有效性
 * @date: 2020-08-11 17:37
 */
public enum CallEfficientEnum {
    /**
     * 有效 即时长不小于30秒
     */
    VALID(1, "有效"),
    /**
     * 无效 时长小于30秒
     */
    INVALID(2, "无效"),
    /**
     * 未拨打电话
     */
    INAPPLICABLE(3, "不适用"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    CallEfficientEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static CallEfficientEnum ofValue(final Integer value) {
        for (final CallEfficientEnum typeEnum : CallEfficientEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }


    /**
     * 获取描述
     *
     * @return 值
     */
    public static String getNameByVale(final Integer value) {
        for (final CallEfficientEnum typeEnum : CallEfficientEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    @JsonValue
    public Integer getValue() {
        return value;
    }
}
