package cn.fw.shirasawa.server.controller.app

import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.enums.AuthType
import cn.fw.shirasawa.service.bus.follow.DebugBizService
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.*
import javax.validation.constraints.NotNull

/**
 * debug类
 *
 * @author : kurisu
 * @version : 1.0
 * @className : DebugController
 * @description : debug类
 * @ignore
 * @date : 2023-03-23 16:04
 */
@RestController
@Authorization(AuthType.NONE)
@Validated
@RequestMapping("/app/debug")
class DebugController(private val debugBizService: DebugBizService) {

    @GetMapping("/fix/telstatus")
    @ControllerMethod("跟进电话数据处理类")
    fun fixTelStatus(@NotNull(message = "集团id不能为空") groupId: Long): Message<Int> {
        val i = debugBizService.fixTelStatus(groupId)
        return success(i)
    }

    @PostMapping("/member/telchange")
    @ControllerMethod("会员电话变更")
    fun memberPhoneChange(
        @RequestParam(name = "memberId") memberId: Long,
        @RequestParam(name = "accountId") accountId: Long
    ): Message<Void> {
        debugBizService.memberPhoneChange(memberId, accountId)
        return success()
    }
}