package cn.fw.shirasawa.server.controller.app;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.LoginAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import cn.fw.shirasawa.domain.dto.FollowAttachmentDTO;
import cn.fw.shirasawa.domain.dto.RecordCompleteDTO;
import cn.fw.shirasawa.service.bus.follow.FollowBizService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * 跟进操作
 *
 * @author : kurisu
 * @className : FollowController
 * @description : 跟进控制器
 * @date: 2020-08-15 16:23
 */
@Slf4j
@RestController
@Authorization(AuthType.APP)
@Validated
@RequestMapping("/app/follow/intent")
public class FollowController {
    private final FollowBizService followBizService;

    @Autowired
    public FollowController(final FollowBizService followBizService) {
        this.followBizService = followBizService;
    }


    /**
     * 主动战败
     *
     * @param currentUser 当前登录用户
     * @param recordId    跟进记录id
     * @param reason      申请战败原因
     * @return
     * @ignoreParams currentUser
     */
    @PostMapping("/defeat")
    @ControllerMethod("主动战败")
    public Message<Void> defeat(@CurrentUser LoginAuthBean currentUser,
                                @NotNull(message = "跟进记录id不能为空") final Long recordId,
                                final String reason) {
        followBizService.defeat(currentUser, recordId, reason);
        return success();
    }


    /**
     * 完成跟进待办
     *
     * @param dto dto
     * @return
     * @ignoreParams userId
     */
    @PostMapping("/todo/complete")
    @ControllerMethod("完成跟进待办")
    public Message<Void> complete(@RequestBody @Valid RecordCompleteDTO dto) {
        followBizService.completeRecord(dto);
        return success();
    }

    /**
     * 上传跟进凭证
     *
     * @param userId userId
     * @param dto    dto
     * @return
     * @ignoreParams userId
     */
    @PostMapping("/todo/upload")
    @ControllerMethod("上传跟进凭证")
    public Message<Void> upload(@CurrentUser Long userId, @RequestBody @Valid final FollowAttachmentDTO dto) {
        followBizService.uploadAtt(dto, userId);
        return success();
    }


    /**
     * 通过智能通话拨打电话
     *
     * @param recordId 跟进记录id
     * @return
     */
    @GetMapping("/call")
    @ControllerMethod("通过智能通话拨打电话")
    public Message<String> call(@NotNull(message = "跟进待办ID不能为空") final Long recordId) {
        return success(followBizService.callSomeone(recordId));
    }
}
