package cn.fw.shirasawa.server.controller.task

import cn.fw.shirasawa.domain.db.follow.FollowTask
import cn.fw.shirasawa.domain.enums.FollowTypeEnum
import cn.fw.shirasawa.domain.enums.TaskStateEnum
import cn.fw.shirasawa.service.bus.FollowExpansionService
import cn.fw.shirasawa.service.data.FollowTaskService
import cn.fw.shirasawa.service.property.FollowTodoProperty
import com.baomidou.mybatisplus.core.toolkit.Wrappers
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty
import org.springframework.scheduling.annotation.Scheduled
import org.springframework.stereotype.Component
import java.time.LocalDateTime

/**
 * 终止事故车跟进待办
 * <p>事故车线索产生72h后自动终止</p>
 * @author : kurisu
 * @version : 1.0
 * @desc : 终止事故车跟进待办
 * @date : 2024-03-01 11:31
 */
@Component
@ConditionalOnProperty(prefix = "task", name = ["switch"], havingValue = "on")
class StopFollowForAccTask(
    private val followTaskService: FollowTaskService,
    private val followExpansionService: FollowExpansionService,
    private val followTodoProperty: FollowTodoProperty
) {

    @Scheduled(initialDelay = 1000 * 10, fixedRate = 1000 * 30)
    fun stopFollowForAccTask() {
        val timeliness = followTodoProperty.accTodoTimeliness ?: 72
        val list = followTaskService.list(
            Wrappers.lambdaQuery<FollowTask>()
                .le(FollowTask::getBeginTime, LocalDateTime.now().minusHours(timeliness.toLong()))
                .eq(FollowTask::getType, FollowTypeEnum.AC)
                .eq(FollowTask::getState, TaskStateEnum.ONGOING)
                .ne(FollowTask::getStopTodo, true)
        )

        if (list.isNullOrEmpty()) {
            return
        }

        CoroutineScope(Dispatchers.IO).launch {
            list.forEach {
                launch {
                    followExpansionService.outTimeStopTodo(it)
                }
            }
        }
    }
}