package cn.fw.shirasawa.component

import cn.fw.member.sdk.event.MemberLatestBindEvent
import cn.fw.shirasawa.domain.db.follow.FollowTask
import cn.fw.shirasawa.domain.enums.TaskStateEnum
import cn.fw.shirasawa.rpc.member.MemberRpcService
import cn.fw.shirasawa.rpc.member.dto.UserAccountDTO
import cn.fw.shirasawa.service.data.FollowTaskService
import com.baomidou.mybatisplus.core.toolkit.Wrappers
import lombok.extern.slf4j.Slf4j
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener
import org.apache.rocketmq.spring.core.RocketMQListener
import org.springframework.stereotype.Component

/**
 * 会员手机变更
 *
 * @author : kurisu
 * @version : 2.1
 * @description : 会员手机变更
 * @date : 2023-04-07 15:12
 */
@Slf4j
@Component
@RocketMQMessageListener(
    topic = MemberLatestBindEvent.TOPIC,
    consumerGroup = "\${spring.application.name}_latest_account"
)
class MemberPhoneChangeConsumer(
    private val memberRpcService: MemberRpcService,
    private val followTaskService: FollowTaskService
) :
    RocketMQListener<MemberLatestBindEvent> {

    override fun onMessage(message: MemberLatestBindEvent?) {
        message ?: return
        val account: UserAccountDTO = memberRpcService.accountById(message.newBindAccountId) ?: return
        with(account) {
            val taskList = followTaskService.list(
                Wrappers.lambdaQuery<FollowTask?>()
                    .eq(FollowTask::getMemberId, message.memberId)
                    .eq(FollowTask::getState, TaskStateEnum.ONGOING)
                    .ne(FollowTask::getContacts, phone)
            )
            if (taskList.isNotEmpty()) {
                taskList.forEach { task -> task.contacts = phone }
                followTaskService.updateBatchById(taskList)
            }
        }
    }
}
