package cn.fw.shirasawa.service.bus

import cn.fw.shirasawa.common.utils.DateUtil
import cn.fw.shirasawa.domain.db.follow.FollowRecord
import cn.fw.shirasawa.domain.db.follow.FollowTask
import cn.fw.shirasawa.domain.enums.BizTypeEnum
import cn.fw.shirasawa.domain.enums.FollowCloseReason
import cn.fw.shirasawa.domain.enums.FollowStatusEnum
import cn.fw.shirasawa.domain.enums.FollowTypeEnum
import cn.fw.shirasawa.rpc.backlog.TodoRpcService
import cn.fw.shirasawa.rpc.backlog.dto.BackLogItemDTO
import cn.fw.shirasawa.sdk.param.StopInShopDTO
import cn.fw.shirasawa.service.data.FollowRecordService
import cn.fw.shirasawa.service.data.FollowTaskService
import com.baomidou.mybatisplus.core.toolkit.Wrappers
import org.springframework.stereotype.Service
import org.springframework.transaction.annotation.Transactional
import java.time.LocalDateTime

/**
 * 跟进拓展处理服务
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 跟进拓展处理服务
 * @date : 2024-03-01 15:00
 */
@Service
class FollowExpansionService(
    private val followRecordService: FollowRecordService,
    private val followTaskService: FollowTaskService,
    private val todoRpcService: TodoRpcService
) {
    @Transactional(rollbackFor = [Exception::class])
    fun outTimeStopTodo(task: FollowTask) {
        outTimeStopTodo(task, false)
    }

    @Transactional(rollbackFor = [Exception::class])
    fun stopClueTodoForInShop(stopInShopDTO: StopInShopDTO) {
        val task = followTaskService.getOne(
            Wrappers.lambdaQuery<FollowTask>()
                .eq(FollowTask::getDetailId, stopInShopDTO.detailId)
                .eq(FollowTask::getGroupId, stopInShopDTO.groupId)
                .eq(FollowTask::getType, FollowTypeEnum.ofValue(stopInShopDTO.type.value))
                .eq(FollowTask::getBizType, BizTypeEnum.ofValue(stopInShopDTO.businessType.value)),
            false
        )
        task?.let {
            outTimeStopTodo(it, true)
        }

    }

    private fun outTimeStopTodo(task: FollowTask, complete: Boolean) {
        val list = followRecordService.list(
            Wrappers.lambdaQuery<FollowRecord>()
                .eq(FollowRecord::getFollowStatus, FollowStatusEnum.ONGOING)
                .eq(FollowRecord::getTaskId, task.id)
                .eq(FollowRecord::getYn, true)
        )

        if (!list.isNullOrEmpty()) {
            list.forEach {
                if (it.addTodo == true) {
                    it.followStatus = FollowStatusEnum.CLOSED
                    it.closeTime = LocalDateTime.now()
                    if (complete) {
                        it.reason = FollowCloseReason.DONE
                        val backLogItemDTO = BackLogItemDTO(
                            it.userId, it.todoCode, it.id.toString(),
                            DateUtil.toDate(LocalDateTime.now()), it.shopId
                        )
                        todoRpcService.complete(backLogItemDTO)
                    } else {
                        it.reason = FollowCloseReason.OVERDUE
                        val dto = BackLogItemDTO(it.userId, it.todoCode, it.id.toString())
                        todoRpcService.cancel(dto)
                    }
                } else {
                    it.yn = false
                }
            }
            followRecordService.updateBatchById(list)
            task.stopTodo = true
            followTaskService.updateById(task)
        }
    }

}