package cn.fw.shirasawa.service.bus.follow

import cn.fw.shirasawa.domain.db.follow.FollowRecord
import cn.fw.shirasawa.domain.db.follow.FollowTask
import cn.fw.shirasawa.domain.db.other.SecretReportHistory
import cn.fw.shirasawa.domain.enums.CallStateEnum
import cn.fw.shirasawa.domain.enums.TaskStateEnum
import cn.fw.shirasawa.rpc.member.MemberRpcService
import cn.fw.shirasawa.rpc.member.dto.UserAccountDTO
import cn.fw.shirasawa.service.data.FollowRecordService
import cn.fw.shirasawa.service.data.FollowTaskService
import cn.fw.shirasawa.service.data.SecretReportHistoryService
import com.baomidou.mybatisplus.core.toolkit.Wrappers
import lombok.extern.slf4j.Slf4j
import org.springframework.stereotype.Service
import org.springframework.transaction.annotation.Transactional

/**
 * 调试类
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 调试类
 * @date : 2023-08-29 17:27
 */
@Service
@Slf4j
class DebugBizService(
    private val followRecordService: FollowRecordService,
    private val memberRpcService: MemberRpcService,
    private val followTaskService: FollowTaskService,
    private val secretReportHistoryService: SecretReportHistoryService
) {

    @Transactional(rollbackFor = [Exception::class])
    fun fixTelStatus(groupId: Long?): Int {
        val list = followRecordService.list(
            Wrappers.lambdaQuery<FollowRecord>()
                .eq(FollowRecord::getGroupId, groupId)
                .eq(FollowRecord::getYn, true)
                .eq(FollowRecord::getAddTodo, true)
                .isNull(FollowRecord::getCalled)
                .last(" limit 500")
        )
        if (list.isEmpty()) {
            return 0
        }

        list.forEach { record ->
            val reportHistoryList = secretReportHistoryService.list(
                Wrappers.lambdaQuery<SecretReportHistory>()
                    .eq(SecretReportHistory::getGroupId, groupId)
                    .eq(SecretReportHistory::getFollowRecordId, record.id)
            )

            if (reportHistoryList.isEmpty()) {
                record.called = CallStateEnum.WAIT_DIAL
            } else {
                val anyMatch = reportHistoryList.any { r -> r.callDuration >= 30L }
                record.called = if (anyMatch) CallStateEnum.EFFECTIVE_DIAL else CallStateEnum.INEFFECTIVE_DIAL
            }

        }

        followRecordService.updateBatchById(list)
        return list.size
    }

    /**
     * 模拟测试会员手机号变更
     */
    fun memberPhoneChange(memberId: Long, accountId: Long) {
        val account: UserAccountDTO = memberRpcService.accountById(accountId) ?: return
        with(account) {
            val taskList = followTaskService.list(
                Wrappers.lambdaQuery<FollowTask?>()
                    .eq(FollowTask::getMemberId, memberId)
                    .eq(FollowTask::getState, TaskStateEnum.ONGOING)
                    .ne(FollowTask::getContacts, phone)
            )
            if (taskList.isNotEmpty()) {
                taskList.forEach { task -> task.contacts = phone }
                followTaskService.updateBatchById(taskList)
            }
        }
    }
}