package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.db.other.OriginalData;
import cn.fw.shirasawa.domain.enums.BizTypeEnum;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.enums.TaskStateEnum;
import cn.fw.shirasawa.domain.vo.follow.AfterSaleCommonDetailVO;
import cn.fw.shirasawa.domain.vo.follow.FollowDetailVO;
import cn.fw.shirasawa.rpc.valhalla.ValhallaRpcService;
import cn.fw.shirasawa.rpc.valhalla.dto.ValhallaCustomerDTO;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : AFFollowStrategy
 * @description : 活动邀约
 * @date: 2022-01-11 15:36
 */
@Slf4j
@Component
@SuppressWarnings("Duplicates")
public class AFFollowStrategy extends AbstractFollowStrategy {

    private final ValhallaRpcService valhallaRpcService;

    @Autowired
    public AFFollowStrategy(final ValhallaRpcService valhallaRpcService) {
        this.valhallaRpcService = valhallaRpcService;
    }

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.AF;
    }


    @Override
    public FollowDetailVO queryDetail(FollowRecord record) {
        FollowTask followTask = followTaskService.getById(record.getTaskId());
        BV.notNull(followTask, "跟进任务不存在");
        AfterSaleCommonDetailVO vo = new AfterSaleCommonDetailVO();
        assembleRecordDetail(vo, record, followTask);
        vo.setTaskDeadline(followTask.getDeadline());

        if (BizTypeEnum.AS.equals(record.getBizType())) {
            ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(record.getVin(), record.getGroupId());
            if (Objects.nonNull(dto)) {
                vo.setCustomerId(dto.getId());
                vo.setPlateNo(dto.getPlateNo());
                vo.setAdviserName(dto.getAdviserName());
                vo.setLastMileage(dto.getCurrentMileage());
                vo.setDeliveryTime(DateUtil.date2LocalDateTime(dto.getArrivalTime()));
                vo.setLoanCustomer(dto.isLoanCustomer());
                vo.setPeriods(dto.getPeriods());
                vo.setExpires(DateUtil.date2LocalDate(dto.getExpires()));
                vo.setInsExpiration(DateUtil.date2LocalDate(dto.getInsuranceExpireDate()));

            }
            vo.setVin(followTask.getVin());
        }
        return vo;
    }

    @Override
    public FollowDetailVO followPoolDetail(FollowTask task) {
        AfterSaleCommonDetailVO vo = new AfterSaleCommonDetailVO();
        vo.setCustomerId(task.getCustomerId());
        vo.setCustomerName(task.getCustomerName());
        vo.setVin(task.getVin());
        vo.setPlateNo(task.getPlateNo());
        vo.setMobile(task.getContacts());
        vo.setRealMobile(task.getContacts());
        vo.setType(task.getType().getValue());
        vo.setBizType(task.getBizType().getValue());
        vo.setTaskId(task.getId());
        vo.setDeadline(task.getDeadline());
        vo.setTimes(task.getTimes());
        if (BizTypeEnum.AS.equals(task.getBizType())) {
            ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(task.getVin(), task.getGroupId());
            if (Objects.nonNull(dto)) {
                vo.setCustomerId(dto.getId());
                vo.setPlateNo(dto.getPlateNo());
                vo.setAdviserName(dto.getAdviserName());
                vo.setLastMileage(dto.getCurrentMileage());
                vo.setDeliveryTime(DateUtil.date2LocalDateTime(dto.getArrivalTime()));
                vo.setLoanCustomer(dto.isLoanCustomer());
                vo.setPeriods(dto.getPeriods());
                vo.setExpires(DateUtil.date2LocalDate(dto.getExpires()));
                vo.setInsExpiration(DateUtil.date2LocalDate(dto.getInsuranceExpireDate()));
            }
        }
        return vo;
    }

    /**
     * 重复校验
     *
     * @param originalData
     * @return
     */
    @Override
    public boolean duplicateCheck(OriginalData originalData) {
        int count = followTaskService.count(Wrappers.<FollowTask>lambdaQuery()
                .eq(FollowTask::getType, originalData.getType())
                .eq(FollowTask::getBizType, originalData.getBizType())
                .eq(FollowTask::getBizId, originalData.getBizId())
                .eq(FollowTask::getDetailId, originalData.getDetailId())
                .eq(FollowTask::getFollowUser, originalData.getUserId())
                .in(FollowTask::getState, TaskStateEnum.ONGOING)
        );
        return count > 0;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void secondTaskStopRecord(final Long taskId) {
        // 没有二次分配
    }
}
