package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.vo.follow.FMDetailVO;
import cn.fw.shirasawa.rpc.valhalla.ValhallaRpcService;
import cn.fw.shirasawa.rpc.valhalla.dto.ValhallaCustomerDTO;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : FMFollowStrategy
 * @description : 首保策略
 * @date: 2020-08-17 10:46
 */
@Slf4j
@Component
public class FMFollowStrategy extends AbstractFollowStrategy {
    private final ValhallaRpcService valhallaRpcService;

    @Autowired
    public FMFollowStrategy(final ValhallaRpcService valhallaRpcService) {
        this.valhallaRpcService = valhallaRpcService;
    }

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.FM;
    }


    @Override
    public FMDetailVO queryDetail(FollowRecord record) {
        FollowTask followTask = followTaskService.getById(record.getTaskId());
        BV.notNull(followTask, "跟进任务不存在");
        FMDetailVO vo = new FMDetailVO();
        assembleRecordDetail(vo, record, followTask);
        vo.setTaskDeadline(followTask.getDeadline());
        vo.setFMExpiration(followTask.getDeadline());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(record.getVin(), record.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setPlateNo(dto.getPlateNo());
            vo.setAdviserName(dto.getAdviserName());
            vo.setBuyDate(DateUtil.date2LocalDateTime(dto.getBuyDate()));
        }
        vo.setVin(followTask.getVin());
        return vo;
    }

    @Override
    public FMDetailVO followPoolDetail(FollowTask task) {
        FMDetailVO vo = new FMDetailVO();
        vo.setCustomerId(task.getCustomerId());
        vo.setCustomerName(task.getCustomerName());
        vo.setPlateNo(task.getPlateNo());
        vo.setVin(task.getVin());
        vo.setType(task.getType().getValue());
        vo.setBizType(task.getBizType().getValue());
        vo.setTaskId(task.getId());
        vo.setDeadline(task.getDeadline());
        vo.setTimes(task.getTimes());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(task.getVin(), task.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setCustomerName(dto.getName());
        }
        return vo;
    }
}
