package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.vo.follow.IRDetailVO;
import cn.fw.shirasawa.rpc.angel.InsurerRpcService;
import cn.fw.shirasawa.rpc.angel.dto.InsuranceDTO;
import cn.fw.shirasawa.rpc.valhalla.ValhallaRpcService;
import cn.fw.shirasawa.rpc.valhalla.dto.ValhallaCustomerDTO;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : IRFollowStrategy
 * @description : 续保策略
 * @date: 2020-08-17 10:48
 */
@Slf4j
@Component
@SuppressWarnings("Duplicates")
public class IRFollowStrategy extends AbstractFollowStrategy {

    private final ValhallaRpcService valhallaRpcService;
    private final InsurerRpcService insurerRpcService;

    @Autowired
    public IRFollowStrategy(final ValhallaRpcService valhallaRpcService,
                            final InsurerRpcService insurerRpcService) {
        this.valhallaRpcService = valhallaRpcService;
        this.insurerRpcService = insurerRpcService;
    }

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.IR;
    }

    @Override
    public IRDetailVO queryDetail(FollowRecord record) {
        FollowTask followTask = followTaskService.getById(record.getTaskId());
        BV.notNull(followTask, "跟进任务不存在");
        IRDetailVO vo = new IRDetailVO();
        assembleRecordDetail(vo, record, followTask);
        vo.setTaskDeadline(followTask.getDeadline());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(record.getVin(), record.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setPlateNo(dto.getPlateNo());
            vo.setLoanCustomer(dto.isLoanCustomer());
            vo.setAdviserName(dto.getAdviserName());
            vo.setPeriods(dto.getPeriods());
            vo.setExpires(DateUtil.date2LocalDate(dto.getExpires()));
        }
        vo.setVin(followTask.getVin());
        InsuranceDTO insuranceDTO = insurerRpcService.queryInsByCustId(vo.getCustomerId());
        if (Objects.nonNull(insuranceDTO)) {
            vo.setTclInsComName(insuranceDTO.getTciInsurerName());
            vo.setTclInsExpiration(DateUtil.date2LocalDateTime(insuranceDTO.getTciExpiryDate()));
            vo.setBusInsComName(insuranceDTO.getInsurerName());
            vo.setBusInsExpiration(DateUtil.date2LocalDateTime(insuranceDTO.getExpiryDate()));
        }
        return vo;
    }

    @Override
    public IRDetailVO followPoolDetail(FollowTask task) {
        IRDetailVO vo = new IRDetailVO();
        vo.setCustomerId(task.getCustomerId());
        vo.setCustomerName(task.getCustomerName());
        vo.setVin(task.getVin());
        vo.setType(task.getType().getValue());
        vo.setBizType(task.getBizType().getValue());
        vo.setTaskId(task.getId());
        vo.setDeadline(task.getDeadline());
        vo.setPlateNo(task.getPlateNo());
        vo.setMobile(task.getContacts());
        vo.setRealMobile(task.getContacts());
        vo.setTimes(task.getTimes());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(task.getVin(), task.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setCustomerName(dto.getName());
            vo.setPlateNo(dto.getPlateNo());
        }
        return vo;
    }
}
