package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.vo.follow.AfterSaleCommonDetailVO;
import cn.fw.shirasawa.domain.vo.follow.FollowDetailVO;
import cn.fw.shirasawa.domain.vo.follow.RMDetailVO;
import cn.fw.shirasawa.rpc.valhalla.ValhallaRpcService;
import cn.fw.shirasawa.rpc.valhalla.dto.ValhallaCustomerDTO;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * 公共池客户跟进
 *
 * @author : kurisu
 * @version : 1.0
 * @className : PLFollowStrategy
 * @description : 公共池客户跟进
 * @date : 2022-07-20 15:17
 */
@Slf4j
@Component
@SuppressWarnings("Duplicates")
public class PLFollowStrategy extends AbstractFollowStrategy {

    private final ValhallaRpcService valhallaRpcService;

    @Autowired
    public PLFollowStrategy(final ValhallaRpcService valhallaRpcService) {
        this.valhallaRpcService = valhallaRpcService;
    }

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.PL;
    }

    @Override
    public AfterSaleCommonDetailVO queryDetail(FollowRecord record) {
        FollowTask followTask = followTaskService.getById(record.getTaskId());
        BV.notNull(followTask, "跟进任务不存在");
        AfterSaleCommonDetailVO vo = new AfterSaleCommonDetailVO();
        assembleRecordDetail(vo, record, followTask);
        vo.setTaskDeadline(followTask.getDeadline());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(record.getVin(), record.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setPlateNo(dto.getPlateNo());
            vo.setAdviserName(dto.getAdviserName());
            vo.setLastMileage(dto.getCurrentMileage());
            vo.setDeliveryTime(DateUtil.date2LocalDateTime(dto.getArrivalTime()));
            vo.setLoanCustomer(dto.isLoanCustomer());
            vo.setPeriods(dto.getPeriods());
            vo.setExpires(DateUtil.date2LocalDate(dto.getExpires()));
            vo.setInsExpiration(DateUtil.date2LocalDate(dto.getInsuranceExpireDate()));

        }
        vo.setVin(followTask.getVin());
        return vo;
    }

    @Override
    public AfterSaleCommonDetailVO followPoolDetail(FollowTask task) {
        AfterSaleCommonDetailVO vo = new AfterSaleCommonDetailVO();
        vo.setCustomerId(task.getCustomerId());
        vo.setCustomerName(task.getCustomerName());
        vo.setVin(task.getVin());
        vo.setPlateNo(task.getPlateNo());
        vo.setMobile(task.getContacts());
        vo.setRealMobile(task.getContacts());
        vo.setType(task.getType().getValue());
        vo.setBizType(task.getBizType().getValue());
        vo.setTaskId(task.getId());
        vo.setDeadline(task.getDeadline());
        vo.setTimes(task.getTimes());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(task.getVin(), task.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setPlateNo(dto.getPlateNo());
            vo.setAdviserName(dto.getAdviserName());
            vo.setLastMileage(dto.getCurrentMileage());
            vo.setDeliveryTime(DateUtil.date2LocalDateTime(dto.getArrivalTime()));
            vo.setLoanCustomer(dto.isLoanCustomer());
            vo.setPeriods(dto.getPeriods());
            vo.setExpires(DateUtil.date2LocalDate(dto.getExpires()));
            vo.setInsExpiration(DateUtil.date2LocalDate(dto.getInsuranceExpireDate()));
        }
        return vo;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void secondTaskStopRecord(final Long taskId) {
        // 没有二次分配
    }
}
