package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.vo.follow.RMDetailVO;
import cn.fw.shirasawa.rpc.valhalla.ValhallaRpcService;
import cn.fw.shirasawa.rpc.valhalla.dto.ValhallaCustomerDTO;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : RMFollowStrategy
 * @description : 流失客户策略
 * @date: 2020-08-17 10:48
 */
@Slf4j
@Component
@SuppressWarnings("Duplicates")
public class RMFollowStrategy extends AbstractFollowStrategy {
    private final ValhallaRpcService valhallaRpcService;

    @Autowired
    public RMFollowStrategy(final ValhallaRpcService valhallaRpcService) {
        this.valhallaRpcService = valhallaRpcService;
    }

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.RM;
    }

    @Override
    public RMDetailVO queryDetail(FollowRecord record) {
        FollowTask followTask = followTaskService.getById(record.getTaskId());
        BV.notNull(followTask, "跟进任务不存在");
        RMDetailVO vo = new RMDetailVO();
        assembleRecordDetail(vo, record, followTask);
        vo.setTaskDeadline(followTask.getDeadline());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(record.getVin(), record.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setPlateNo(dto.getPlateNo());
            vo.setAdviserName(dto.getAdviserName());
            vo.setLastMileage(dto.getCurrentMileage());
            vo.setDeliveryTime(DateUtil.date2LocalDateTime(dto.getArrivalTime()));
        }
        vo.setVin(followTask.getVin());
        return vo;
    }

    @Override
    public RMDetailVO followPoolDetail(FollowTask task) {
        RMDetailVO vo = new RMDetailVO();
        vo.setCustomerId(task.getCustomerId());
        vo.setCustomerName(task.getCustomerName());
        vo.setVin(task.getVin());
        vo.setPlateNo(task.getPlateNo());
        vo.setMobile(task.getContacts());
        vo.setRealMobile(task.getContacts());
        vo.setType(task.getType().getValue());
        vo.setBizType(task.getBizType().getValue());
        vo.setTaskId(task.getId());
        vo.setDeadline(task.getDeadline());
        vo.setTimes(task.getTimes());
        ValhallaCustomerDTO dto = valhallaRpcService.queryByVin(task.getVin(), task.getGroupId());
        if (Objects.nonNull(dto)) {
            vo.setCustomerId(dto.getId());
            vo.setCustomerName(dto.getName());
        }
        return vo;
    }

}
