package cn.fw.shirasawa.service.data.impl;

import cn.fw.shirasawa.dao.mapper.TaskNextPlanMapper;
import cn.fw.shirasawa.domain.db.follow.TaskNextPlan;
import cn.fw.shirasawa.service.data.TaskNextPlanService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.Objects;

/**
 * 任务下次跟进计划
 *
 * @author : kurisu
 * @version : 1.1
 * @className : TaskNextPlanServiceImpl
 * @description : 任务下次跟进计划
 * @date : 2023-04-03 14:58
 */
@Service
public class TaskNextPlanServiceImpl extends ServiceImpl<TaskNextPlanMapper, TaskNextPlan> implements TaskNextPlanService {
    @Override
    public TaskNextPlan queryByTaskId(Long taskId) {
        return getOne(Wrappers.<TaskNextPlan>lambdaQuery()
                        .eq(TaskNextPlan::getTaskId, taskId)
                , Boolean.FALSE);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void stopFollow(Long taskId) {
        update(Wrappers.<TaskNextPlan>lambdaUpdate()
                .set(TaskNextPlan::getEffective, Boolean.FALSE)
                .eq(TaskNextPlan::getTaskId, taskId)
        );
    }

    @Override
    public void recordNextTime(Long taskId, LocalDate nextDate) {
        TaskNextPlan nextPlan = getOne(Wrappers.<TaskNextPlan>lambdaQuery()
                        .eq(TaskNextPlan::getTaskId, taskId)
                , Boolean.FALSE);
        if (Objects.isNull(nextPlan)) {
            TaskNextPlan plan = new TaskNextPlan();
            plan.setTaskId(taskId);
            plan.setPlanTime(nextDate);
            plan.setEffective(Boolean.TRUE);
            this.save(plan);
            return;
        }

        update(Wrappers.<TaskNextPlan>lambdaUpdate()
                .set(TaskNextPlan::getPlanTime, nextDate)
                .eq(TaskNextPlan::getTaskId, taskId)
                .eq(TaskNextPlan::getEffective, Boolean.TRUE)
        );
    }
}
